@@ -3,11 +3,11 @@ from pandagg.node.query.compound import CompoundClause
 
 class ScriptScore(CompoundClause):
     _default_operator = "query"
-    _parent_params = ["query"]
+    _parent_params = {"query": False}
     KEY = "script_score"
 
 
 class PinnedQuery(CompoundClause):
     _default_operator = "organic"
-    _parent_params = ["organic"]
+    _parent_params = {"organic": False}
     KEY = "pinned"
