@@ -9,8 +9,8 @@ from lighttree.exceptions import NotFoundNodeError
 from pandagg.connections import get_connection
 from pandagg.query import Bool
 from pandagg.response import Response
-from pandagg.tree.mapping import Mapping
-from pandagg.tree.query.abstract import Query
+from pandagg.tree.mapping import _mapping
+from pandagg.tree.query.abstract import Query, ADD
 from pandagg.tree.aggs.aggs import Aggs
 from pandagg.utils import DSLMixin
 
@@ -127,7 +127,7 @@ class Search(DSLMixin, Request):
         self._highlight_opts = {}
         self._suggest = {}
         self._script_fields = {}
-        mapping = Mapping(mapping)
+        mapping = _mapping(mapping)
         self._mapping = mapping
         self._aggs = Aggs(mapping=mapping, nested_autocorrect=nested_autocorrect)
         self._query = Query(mapping=mapping, nested_autocorrect=nested_autocorrect)
@@ -137,52 +137,138 @@ class Search(DSLMixin, Request):
         self._repr_auto_execute = repr_auto_execute
         super(Search, self).__init__(using=using, index=index)
 
-    def query(self, *args, **kwargs):
+    def query(self, type_or_query, insert_below=None, on=None, mode=ADD, **body):
         s = self._clone()
-        s._query = s._query.query(*args, **kwargs)
+        s._query = s._query.query(
+            type_or_query, insert_below=insert_below, on=on, mode=mode, **body
+        )
         return s
 
     query.__doc__ = Query.query.__doc__
 
-    def bool(self, *args, **kwargs):
+    def bool(
+        self,
+        must=None,
+        should=None,
+        must_not=None,
+        filter=None,
+        insert_below=None,
+        on=None,
+        mode=ADD,
+        **body
+    ):
         s = self._clone()
-        s._query = s._query.bool(*args, **kwargs)
+        s._query = s._query.bool(
+            must=must,
+            should=should,
+            filter=filter,
+            must_not=must_not,
+            insert_below=insert_below,
+            on=on,
+            mode=mode,
+            **body
+        )
         return s
 
     bool.__doc__ = Query.bool.__doc__
 
-    def filter(self, *args, **kwargs):
+    def filter(
+        self,
+        type_or_query,
+        insert_below=None,
+        on=None,
+        mode=ADD,
+        bool_body=None,
+        **body
+    ):
         s = self._clone()
-        s._query = s._query.filter(*args, **kwargs)
+        s._query = s._query.filter(
+            type_or_query,
+            insert_below=insert_below,
+            on=on,
+            mode=mode,
+            bool_body=bool_body,
+            **body
+        )
         return s
 
     filter.__doc__ = Query.filter.__doc__
 
-    def must_not(self, *args, **kwargs):
+    def must_not(
+        self,
+        type_or_query,
+        insert_below=None,
+        on=None,
+        mode=ADD,
+        bool_body=None,
+        **body
+    ):
         s = self._clone()
-        s._query = s._query.must_not(*args, **kwargs)
+        s._query = s._query.must_not(
+            type_or_query,
+            insert_below=insert_below,
+            on=on,
+            mode=mode,
+            bool_body=bool_body,
+            **body
+        )
         return s
 
     must_not.__doc__ = Query.must_not.__doc__
 
-    def should(self, *args, **kwargs):
+    def should(
+        self,
+        type_or_query,
+        insert_below=None,
+        on=None,
+        mode=ADD,
+        bool_body=None,
+        **body
+    ):
         s = self._clone()
-        s._query = s._query.should(*args, **kwargs)
+        s._query = s._query.should(
+            type_or_query,
+            insert_below=insert_below,
+            on=on,
+            mode=mode,
+            bool_body=bool_body,
+            **body
+        )
         return s
 
     should.__doc__ = Query.should.__doc__
 
-    def must(self, *args, **kwargs):
+    def must(
+        self,
+        type_or_query,
+        insert_below=None,
+        on=None,
+        mode=ADD,
+        bool_body=None,
+        **body
+    ):
         s = self._clone()
-        s._query = s._query.must(*args, **kwargs)
+        s._query = s._query.must(
+            type_or_query,
+            insert_below=insert_below,
+            on=on,
+            mode=mode,
+            bool_body=bool_body,
+            **body
+        )
         return s
 
     must.__doc__ = Query.must.__doc__
 
-    def exclude(self, *args, **kwargs):
+    def exclude(self, type_or_query, insert_below=None, on=None, mode=ADD, **body):
         """Must not wrapped in filter context."""
         s = self._clone()
-        s._query = s._query.filter(Bool(must_not=[Query(*args, **kwargs)]))
+        s._query = s._query.filter(
+            Bool(must_not=Query._translate_query(type_or_query=type_or_query, **body)),
+            insert_below=insert_below,
+            on=on,
+            mode=mode,
+        )
         return s
 
     def post_filter(self, *args, **kwargs):
@@ -190,16 +276,35 @@ class Search(DSLMixin, Request):
         s._post_filter = s._post_filter.query(*args, **kwargs)
         return s
 
-    def aggs(self, *args, **kwargs):
+    def agg(self, name, type_or_agg=None, insert_below=None, at_root=False, **body):
         s = self._clone()
-        s._aggs = s._aggs.aggs(*args, **kwargs)
+        s._aggs = s._aggs.agg(
+            name,
+            type_or_agg=type_or_agg,
+            insert_below=insert_below,
+            at_root=at_root,
+            **body
+        )
+        return s
+
+    agg.__doc__ = Aggs.agg.__doc__
+
+    def aggs(self, aggs, insert_below=None, at_root=False):
+        s = self._clone()
+        s._aggs = s._aggs.aggs(aggs, insert_below=insert_below, at_root=at_root)
         return s
 
     aggs.__doc__ = Aggs.aggs.__doc__
 
-    def groupby(self, *args, **kwargs):
+    def groupby(self, name, type_or_agg=None, insert_below=None, at_root=None, **body):
         s = self._clone()
-        s._aggs = s._aggs.groupby(*args, **kwargs)
+        s._aggs = s._aggs.groupby(
+            name,
+            type_or_agg=type_or_agg,
+            insert_below=insert_below,
+            at_root=at_root,
+            **body
+        )
         return s
 
     groupby.__doc__ = Aggs.groupby.__doc__
@@ -239,7 +344,7 @@ class Search(DSLMixin, Request):
             if self._mapping:
                 for key in n:
                     try:
-                        self._mapping.get(key)
+                        self._mapping.id_from_key(key)
                     except NotFoundNodeError:
                         raise KeyError("%s not in index" % key)
             return self.source(includes=n)
@@ -301,7 +406,7 @@ class Search(DSLMixin, Request):
         s._aggs = self._aggs.clone()
         s._query = self._query.clone()
         s._post_filter = self._post_filter.clone()
-        s._mapping = self._mapping.clone()
+        s._mapping = None if self._mapping is None else self._mapping.clone()
         s._repr_auto_execute = self._repr_auto_execute
         return s
 
@@ -609,7 +714,7 @@ class Search(DSLMixin, Request):
             import pandas as pd  # noqa
         except ImportError:
             return ImportError("repr_auto_execute requires pandas dependency")
-        if not self._aggs.is_empty():
+        if self._aggs.to_dict():
             # hits are not necessary to display aggregation results
             r = self.size(0).execute()
             return r.aggregations.to_dataframe()
