@@ -8,21 +8,25 @@ from future.utils import iteritems
 from pandagg.node.query.joining import Nested
 from pandagg.tree._tree import Tree
 
-from pandagg.node.response.bucket import Bucket
-from pandagg.node.aggs.abstract import UniqueBucketAgg, ShadowRoot
+from pandagg.node.response.bucket import Bucket, BucketNode
 from pandagg.tree.query.abstract import Query
 
 
 class AggsResponseTree(Tree):
-    """Tree representation of an ElasticSearch response.
-    """
+    """Tree representation of an ElasticSearch response."""
 
-    def __init__(self, aggs):
+    node_class = BucketNode
+
+    def __init__(self, aggs, raw_response=None):
         """
         :param aggs: instance of pandagg.agg.Agg from which this Elasticsearch response originates.
         """
         super(AggsResponseTree, self).__init__()
         self.__aggs = aggs
+        root_node = BucketNode()
+        self.insert_node(root_node)
+        if raw_response:
+            self.parse(raw_response)
 
     def _clone_init(self, deep=False):
         return AggsResponseTree(aggs=self.__aggs.clone(deep=deep))
@@ -30,45 +34,35 @@ class AggsResponseTree(Tree):
     def parse(self, raw_response):
         """Build response tree from ElasticSearch aggregation response
 
-        Note: if the root aggregation node can generate multiple buckets, a response root is crafted to avoid having
-        multiple roots.
-
         :param raw_response: ElasticSearch aggregation response
         :return: self
         """
-        root_node = self.__aggs.get(self.__aggs.root)
-        pid = None
-
-        if not isinstance(root_node, UniqueBucketAgg):
-            bucket = Bucket(value=None)
-            pid = bucket.identifier
-            self.insert_node(bucket, None)
-
-        self._parse_node_with_children(root_node, raw_response, pid=pid)
+        _, agg_root_node = self.__aggs.get(self.__aggs.root)
+        for child_name, child in self.__aggs.children(agg_root_node.identifier):
+            self._parse_node_with_children(
+                child_name, agg_node=child, raw_response=raw_response, pid=self.root
+            )
         return self
 
-    def _parse_node_with_children(self, agg_node, raw_response, pid=None):
+    def _parse_node_with_children(self, agg_name, agg_node, raw_response, pid):
         """Recursive method to parse ES raw response.
 
         :param agg_node: current aggregation, pandagg.nodes.AggNode instance
         :param raw_response: ES response at current level, dict
         :param pid: parent node identifier
         """
-        agg_raw_response = (
-            raw_response
-            if isinstance(agg_node, ShadowRoot)
-            else raw_response.get(agg_node.name)
-        )
+        agg_raw_response = raw_response.get(agg_name)
         for key, raw_value in agg_node.extract_buckets(agg_raw_response):
             bucket = Bucket(
-                level=agg_node.name,
-                key=key,
-                value=agg_node.extract_bucket_value(raw_value),
+                level=agg_name, key=key, value=agg_node.extract_bucket_value(raw_value)
             )
-            self.insert_node(bucket, pid)
-            for child in self.__aggs.children(agg_node.name, id_only=False):
+            self.insert_node(bucket, parent_id=pid)
+            for child_name, child in self.__aggs.children(agg_node.identifier):
                 self._parse_node_with_children(
-                    agg_node=child, raw_response=raw_value, pid=bucket.identifier
+                    child_name,
+                    agg_node=child,
+                    raw_response=raw_value,
+                    pid=bucket.identifier,
                 )
 
     def bucket_properties(self, bucket, properties=None, end_level=None, depth=None):
@@ -83,11 +77,11 @@ class AggsResponseTree(Tree):
         """
         if properties is None:
             properties = OrderedDict()
-        if bucket.level != Bucket.ROOT_NAME:
+        if bucket.level is not None:
             properties[bucket.level] = bucket.key
         if depth is not None:
             depth -= 1
-        parent = self.parent(bucket.identifier, id_only=False)
+        _, parent = self.parent(bucket.identifier)
         if bucket.level == end_level or depth == 0 or parent is None:
             return properties
         return self.bucket_properties(parent, properties, end_level, depth)
@@ -96,8 +90,7 @@ class AggsResponseTree(Tree):
     def _build_filter(
         cls, nid_to_children, filters_per_nested_level, current_nested_path=None
     ):
-        """Recursive function to build bucket filters from highest to deepest nested conditions.
-        """
+        """Recursive function to build bucket filters from highest to deepest nested conditions."""
         current_conditions = filters_per_nested_level.get(current_nested_path, [])
         nested_children = nid_to_children[current_nested_path]
         for nested_child in nested_children:
@@ -128,10 +121,11 @@ class AggsResponseTree(Tree):
         """
         tree_mapping = self.__aggs.mapping
 
-        selected_bucket = self.get(nid)
+        b_key, selected_bucket = self.get(nid)
         bucket_properties = self.bucket_properties(selected_bucket)
         agg_node_key_tuples = [
-            (self.__aggs.get(level), key) for level, key in iteritems(bucket_properties)
+            (self.__aggs.get(self.__aggs.id_from_key(level))[1], key)
+            for level, key in iteritems(bucket_properties)
         ]
 
         filters_per_nested_level = defaultdict(list)
