@@ -6,5 +6,5 @@ class ResponseBucketTestCase(TestCase):
     def test_bucket(self):
         self.assertEqual(
             Bucket(level="windows.color", key="green", value=32).line_repr(depth=5),
-            "windows.color=green                   32",
+            ("windows.color=green", "32"),
         )
